@@ -6,7 +6,6 @@ import requests
 from sentry.plugins.bases.notify import NotificationPlugin
 
 import sentry_dingding
-import requests
 from .forms import DingDingOptionsForm
 
 DingTalk_API = "https://oapi.dingtalk.com/robot/send?access_token={token}"
@@ -18,7 +17,7 @@ class DingDingPlugin(NotificationPlugin):
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
-    version = '1.0.14'
+    version = '1.0.16'
     description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/dreamerldq/sentry-dingding-format'),
@@ -42,7 +41,7 @@ class DingDingPlugin(NotificationPlugin):
         self.post_process(group, event, *args, **kwargs)
 
     def getGroupCount(self, groupId):
-        url = '/api/0/issues/{groupId}/'.format(groupId =groupId )
+        url = 'http://localhost:9000/api/0/issues/{groupId}/'.format(groupId =groupId )
         r = requests.get(url).json()
         return r["count"]
 
